![duality-header](https://raw.githubusercontent.com/dkundih/duality/main/_logistics/duality.jpg)

[![Downloads](https://img.shields.io/pypi/dm/duality?color=F43&label=Downloads&style=flat-square)](https://pypi.org/project/duality)
[![License](https://img.shields.io/pypi/l/duality?color=178&label=License&style=flat-square)](https://github.com/dkundih/duality/blob/main/LICENSE)
[![PyPi version](https://img.shields.io/pypi/v/duality?color=178&&label=PyPi%20version&style=flat-square)](https://pypi.org/project/duality)
[![Python version](https://img.shields.io/pypi/pyversions/duality?color=178&label=Python%20version&style=flat-square)](https://pypi.org/project/duality)
[![Latest publish](https://img.shields.io/github/last-commit/dkundih/duality?color=178&label=Latest%20publish&style=flat-square)](https://github.com/dkundih/duality)
[![Format](https://img.shields.io/pypi/format/duality?color=178&label=Format&style=flat-square)](https://pypi.org/project/duality)

duality
=====

Decorator library for the creation of CLI applications and scripts.
Use permitted according to the terms of use and conditions set by the attached license.


**Example of use - SCRIPT**

Example code over a Car object. - DualityApp.script (v5.3.3)
<img src='https://raw.githubusercontent.com/dkundih/duality/main/_logistics/T_dynamicScript1.jpg'/>

Example use in the terminal. - DualityApp.script (v5.3.3)
<img src='https://raw.githubusercontent.com/dkundih/duality/main/_logistics/T_dynamicScript2.jpg'/>


**Example of use - WHEEL**

Example code over a Car object. - DualityApp.wheel (v5.3.3)
<img src='https://raw.githubusercontent.com/dkundih/duality/main/_logistics/T_dynamicWheel1.jpg'/>

Example use in the terminal. - DualityApp.wheel (v5.3.3)
<img src='https://raw.githubusercontent.com/dkundih/duality/main/_logistics/T_dynamicWheel2.jpg'/>

Visit my Data Library at https://github.com/dkundih/DataLibrary in order to see the demonstration of use in practical examples.

**Example of use - APPLY CUSTOM COLORING**

Example code for the creation of a university with custom coloring defined in the 'myset' dictionary. (v5.3.3)

NOTE: Fore coloring is defined as F(c, m, y, k, r, g, b) - for example, 'Fr' stands for fore coloring in red.

Background coloring is defined as B(c, m, y, k, r, g, b) - for example, 'Br' stands for background coloring in red.

Dictionary keys must be named as shown, only coloring values are subject to change.

In order to apply custom coloring, define color_mode = 'custom', custom_color_mode = your_dictionary_name_here.

<img src='https://raw.githubusercontent.com/dkundih/duality/main/_logistics/T_customColoring1.jpg'/>

Example use in the terminal with custom coloring applied. (v5.3.3)
<img src='https://raw.githubusercontent.com/dkundih/duality/main/_logistics/T_customColoring2.jpg'/>

**Installation**

```sh
# using pip
pip install duality
```
**Import**

```sh
# for Python environment
import duality
```

**A word from the author!**

The module itself, it's maintenance, updates and stability, logo, videos, promotional materials and everything associated with duality are done by **David Kundih** from **Croatia**.

<h1 align='center'> Hi! :wave:</h1>
 
<img src='https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/BLUERED_GHiLI.jpg'/>

<p align='center'>
My name is <b>David Kundih</b> and I am a Master's student of <b>Sustainable mobility and logistics</b> at the <b>University North</b>, currently specializing in <b>Digital transformation of traffic and logistics using Python.</b>
</p>
 
<h4 align='center'>My latest projects:</h4>
<p align='center'>
<a href="https://github.com/dkundih/vandal">vandal</p>  
<p align='center'>
<a href="https://github.com/dkundih/duality">duality</p>
<p align='center'>
<a href="https://github.com/dkundih/logistics">logistics</p>    
<p align='center'>
<a href="https://github.com/dkundih/unin">unin</a></p>
</p>

<h3 align='center'><i>People shine the brightest when they seek to understand what kind of love sustains them.</i></h3>

<p align='center'>
<a href="https://www.instagram.com/dkundih/"><img height="25" src="https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/instagram.jpg"></a>
<a href="https://www.facebook.com/dkundih/"><img height="25" src="https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/fb.jpg"></a>
<a href="https://www.linkedin.com/in/dkundih/"><img height="25" src="https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/linkedin.png"></a>
<a href="https://www.pypi.org/user/dkundih/"><img height="25" src="https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/pypi.jpg"></a>
<a href="https://www.buymeacoffee.com/dkundih"><img height="25" src="https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/buymeacoffee.jpg"></a>
<a href="https://www.patreon.com/dkundih"><img height="25" src="https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/patreon.jpg"></a>
<a href="https://www.behance.net/dkundih"><img height="25" src="https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/behance.jpg"></a>
<a href="https://www.researchgate.net/profile/David-Kundih"><img height="25" src="https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/rg.jpg"></a>
